@@ -5,7 +5,7 @@ use Tie::Cache::LRU 0.21;
 
 use vars qw($VERSION);
 
-$VERSION="0.53";
+$VERSION="0.54";
 
 sub TIEHASH {
   my $class = shift;
@@ -76,6 +76,11 @@ sub NEXTKEY {
 sub DESTROY {
 }
 
+sub CLEAR {
+    my ($self) = @_;
+    $self->{LRUOBJ}->CLEAR();
+}
+
 sub EXISTS {
   my $self = shift;
   my $key  = shift;
@@ -135,6 +140,12 @@ Tie::Cache::LRU::Expires - Extends Tie::Cache::LRU with expiring
         sleep 4;
 	for(1100..1110) { print $cache{$_},"\n"; }	# now also expired.
 
+	# Clearing the cache
+
+	%cache=();
+
+
+
 =head1 DESCRIPTION
 
 This is an expiring LRU cache, using Tie::Cache::LRU. Each entry
